@@ -4,6 +4,9 @@ Workflow which exercises the common tasks in an end to end scenario
 from dkist_processing_common.tasks.l1_output_data import AddDatasetReceiptAccount
 from dkist_processing_common.tasks.l1_output_data import PublishCatalogAndQualityMessages
 from dkist_processing_common.tasks.l1_output_data import TransferL1Data
+from dkist_processing_common.tasks.quality_metrics import QualityL0Metrics
+from dkist_processing_common.tasks.quality_metrics import QualityL1Metrics
+from dkist_processing_common.tasks.submit_quality import SubmitQuality
 from dkist_processing_common.tasks.teardown import Teardown
 from dkist_processing_common.tasks.transfer_input_data import TransferL0Data
 from dkist_processing_core import Workflow
@@ -26,6 +29,24 @@ parse_input_data = Workflow(
 )
 parse_input_data.add_node(task=ParseL0TestInputData, upstreams=None)
 
+# L0Quality Task
+parse_input_data = Workflow(
+    process_category="test", process_name="quality_l0_metrics", workflow_package=__package__
+)
+parse_input_data.add_node(task=QualityL0Metrics, upstreams=None)
+
+# L1Quality Task
+parse_input_data = Workflow(
+    process_category="test", process_name="quality_l1_metrics", workflow_package=__package__
+)
+parse_input_data.add_node(task=QualityL1Metrics, upstreams=None)
+
+# SubmitQuality Task
+parse_input_data = Workflow(
+    process_category="test", process_name="quality_submit_metrics", workflow_package=__package__
+)
+parse_input_data.add_node(task=SubmitQuality, upstreams=None)
+
 # GenerateL1CalibratedData Task
 generate_calibrated_data = Workflow(
     process_category="test", process_name="generate_calibrated_data", workflow_package=__package__
